"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.cssPlugin = void 0;
const path = require("path");
const parseBundle_1 = require("./parseBundle");
const removeRange = (code, range) => `${code.slice(0, range.start)}${code.slice(range.end)}`;
const cssPlugin = (session, filter) => ({
    resolveId: (importee, importer) => {
        const id = path.isAbsolute(importee) || !importer ? importee : path.join(path.dirname(importer), importee);
        return id === session.helperPath ? { id, external: true, moduleSideEffects: false } : null;
    },
    async load(id) {
        if (filter(id)) {
            let { code } = await session.processCSS(id);
            const { body } = this.parse(code, {});
            for (let { length: index } = body; 0 < index--;) {
                const node = body[index];
                if (node.type === 'ImportDeclaration') {
                    const source = path.join(path.dirname(id), node.source.value);
                    if (source === session.helperPath) {
                        code = removeRange(code, node);
                    }
                }
            }
            return code;
        }
        return null;
    },
    generateBundle(_options, bundle) {
        const cssList = [];
        (0, parseBundle_1.parseBundle)({
            bundle,
            cssKey: session.configuration.cssKey,
        }).chunks.forEach(({ chunk, css }) => {
            chunk.code = css.expressionStatements
                .sort((range1, range2) => range1.start < range2.start ? 1 : -1)
                .reduce(removeRange, chunk.code);
            cssList.push(css.ranges.map((range) => range.css).join('\n').trim());
        });
        this.emitFile({
            type: 'asset',
            fileName: session.configuration.output.path,
            source: cssList.join('\n'),
        });
    },
});
exports.cssPlugin = cssPlugin;
