"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.embedCSSPlugin = void 0;
const path = require("path");
const esifycss = require("esifycss");
const pluginUtils = require("rollup-pluginutils");
const getFirstInput_1 = require("./getFirstInput");
const cssPlugin_1 = require("./cssPlugin");
const scriptPlugin_1 = require("./scriptPlugin");
const defaultPlugin_1 = require("./defaultPlugin");
const embedCSSPlugin = (pluginOptions = {}) => {
    let core = (0, defaultPlugin_1.defaultPlugin)();
    return {
        name: 'embedCSS',
        buildStart(inputOptions) {
            let { helper } = pluginOptions;
            if (!pluginOptions.css && !helper) {
                const firstInput = (0, getFirstInput_1.getFirstInput)(inputOptions.input);
                if (firstInput) {
                    helper = path.join(path.dirname(firstInput), 'embedcss-helper.css.js');
                }
            }
            let helperId;
            if (helper) {
                helperId = path.join(__dirname, `esifycss-helper${path.extname(helper || 's.js')}`);
            }
            let css = pluginOptions.css ? pluginOptions.css : undefined;
            if (typeof css === 'boolean') {
                css = 'esifycssOutput.css';
            }
            const session = new esifycss.Session({
                ...pluginOptions,
                helper: helperId,
                css,
                include: [],
                watch: false,
            });
            const filter = pluginUtils.createFilter(pluginOptions.include || './**/*.css', pluginOptions.exclude);
            if (session.configuration.output.type === 'css') {
                core = (0, cssPlugin_1.cssPlugin)(session, filter);
            }
            else {
                core = (0, scriptPlugin_1.scriptPlugin)(session, filter);
            }
        },
        async resolveId(importee, importer, options) {
            return await core.resolveId.call(this, importee, importer, options);
        },
        async load(id) {
            return await core.load.call(this, id);
        },
        async generateBundle(options, bundle, isWrite) {
            await core.generateBundle.call(this, options, bundle, isWrite);
        },
    };
};
exports.embedCSSPlugin = embedCSSPlugin;
