"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.parseBundle = void 0;
const esifycss = require("esifycss");
const parseBundle = ({ bundle, cssKey }) => {
    const tokens = new Map();
    const chunks = [];
    const processed = new WeakSet();
    const process = (chunkOrName) => {
        const chunk = typeof chunkOrName === 'string' ? bundle[chunkOrName] : chunkOrName;
        if (typeof chunk === 'undefined' || chunk.type === 'asset' || processed.has(chunk)) {
            return;
        }
        processed.add(chunk);
        chunk.imports.forEach(process);
        chunk.dynamicImports.forEach(process);
        const css = esifycss.parseCSSModuleScript({ code: chunk.code, cssKey });
        for (const range of css.ranges) {
            for (const token of esifycss.tokenizeString(range.css)) {
                tokens.set(token, (tokens.get(token) || 0) + 1);
            }
        }
        chunks.push({ chunk, css });
    };
    Object.values(bundle).forEach(process);
    return { tokens, chunks };
};
exports.parseBundle = parseBundle;
