"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.scriptPlugin = void 0;
const path = require("path");
const esifycss = require("esifycss");
const parseBundle_1 = require("./parseBundle");
const scriptPlugin = (session, filter) => ({
    resolveId(importee, importer) {
        const id = importer && !path.isAbsolute(importee) ? path.join(path.dirname(importer), importee) : importee;
        return id === session.configuration.output.path ? session.helperPath : null;
    },
    async load(id) {
        if (!filter(id)) {
            return null;
        }
        return (await session.processCSS(id)).code;
    },
    generateBundle(_options, bundle) {
        const { chunks, tokens } = (0, parseBundle_1.parseBundle)({
            bundle,
            cssKey: session.configuration.cssKey,
        });
        const identifier = esifycss.createOptimizedIdGenerator(tokens);
        for (const { chunk, css } of chunks) {
            let code = esifycss.minifyCSSInScript(chunk.code, css.ranges, identifier);
            code = esifycss.setDictionary(code, identifier.idList);
            chunk.code = code;
        }
    },
});
exports.scriptPlugin = scriptPlugin;
